@@ -39,7 +39,9 @@
 #include <ufs/ffs/fs.h>
 #include <ufs/ufs/quota.h>
 #include <ufs/ufs/inode.h>
+#ifndef AFS_OBSD38_ENV
 #include <ufs/ufs/extattr.h>
+#endif
 #include <ufs/ufs/ufsmount.h>
 #ifndef MLEN
 #include <sys/mbuf.h>
@@ -64,26 +66,44 @@
 #include <linux/backing-dev.h>
 #include <linux/pagemap.h>
 #include <linux/namei.h>
+#ifdef STRUCT_INODE_HAS_I_SECURITY
+#include <linux/security.h>
+#endif
+#include <linux/suspend.h>
+#if defined(LINUX_KEYRING_SUPPORT)
+#include <linux/rwsem.h>
+#include <linux/key.h>
+#endif
 #endif
 /* Avoid conflicts with coda overloading AFS type namespace. Must precede
  * inclusion of uaccess.h.
  */
+#ifndef _LINUX_CODA_FS_I
 #define _LINUX_CODA_FS_I
+#define _CODA_HEADER_
 #define _CFS_HEADER_
 struct coda_inode_info {
 };
+#endif
+#ifndef _LINUX_XFS_FS_I
 #define _LINUX_XFS_FS_I
 struct xfs_inode_info {
 };
+#endif
 #include <asm/uaccess.h>
 #include <linux/list.h>
 #include <linux/dcache.h>
+#include <linux/mount.h>
 #include <linux/fs.h>
 #include <linux/quota.h>
 #include <linux/sched.h>
 #include <linux/mm.h>
+#include <linux/slab.h>
 #include <linux/string.h>
 #include <asm/semaphore.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
+#include <linux/mutex.h>
+#endif
 #include <linux/errno.h>
 #ifdef COMPLETION_H_EXISTS
 #include <linux/completion.h>
@@ -136,6 +156,12 @@ typedef unsigned short etap_event_t;
 #include "sys/cmn_err.h"
 #ifdef AFS_SGI64_ENV
 #include <ksys/behavior.h>
+/* in 6.5.20f, ksys/behavior.h doesn't bother to define BHV_IS_BHVL,
+ * but sys/vnode.h uses it in VNODE_TO_FIRST_BHV. It looks like from
+ * older headers like we want the old behavior, so we fake it. */
+#if defined(BHV_PREPARE) && !defined(CELL_CAPABLE)
+#define BHV_IS_BHVL(bhp) (0)
+#endif
 #endif /* AFS_SGI64_ENV */
 #include "fs/efs_inode.h"
 #ifdef AFS_SGI_EFS_IOPS_ENV
@@ -182,11 +208,15 @@ typedef unsigned short etap_event_t;
 #include "h/stream.h"		/* stops SUN56 socketvar.h errors */
 #endif
 
+#ifdef AFS_SUN510_ENV
+#include <sys/cred_impl.h>
+#endif
+
 #include "h/socket.h"
 #include "h/socketvar.h"
 #include "h/protosw.h"
 
-#if defined(AFS_SGI_ENV) || defined(AFS_SUN_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_SGI_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_FBSD_ENV)
 #  include "h/dirent.h"
 #  ifdef	AFS_SUN5_ENV
 #    include "h/sysmacros.h"
@@ -196,12 +226,7 @@ typedef unsigned short etap_event_t;
 #  include "h/dir.h"
 #endif /* SGI || SUN || HPUX */
 
-#ifdef AFS_DEC_ENV
-#  include "h/smp_lock.h"
-#endif /* AFS_DEC_ENV */
-
-
-#if !defined(AFS_SGI64_ENV) && !defined(AFS_FBSD_ENV)
+#if !defined(AFS_SGI64_ENV) && !defined(AFS_FBSD_ENV) && !defined(AFS_DARWIN80_ENV)
 #include "h/user.h"
 #endif /* AFS_SGI64_ENV */
 #define	MACH_USER_API	1
@@ -216,24 +241,6 @@ typedef unsigned short etap_event_t;
 
 
 /* ----- The following mainly deal with vnodes/inodes stuff ------ */
-#ifdef	AFS_DEC_ENV
-#  include "h/mount.h"
-#  include "machine/psl.h"
-#  include "afs/gfs_vnode.h"
-#endif
-
-#ifdef	AFS_MACH_ENV
-#    include <vfs/vfs.h>
-#    include <vfs/vnode.h>
-#    include <sys/inode.h>
-#    include <sys/mount.h>
-#    include <vm/vm_pager.h>
-#    include <kern/mfs.h>
-#    include <mach/vm_param.h>
-#    include <kern/parallel.h>
-#endif /* AFS_MACH_ENV */
-
-#ifndef AFS_DEC_ENV
 #  ifdef	AFS_SUN5_ENV
 #    include "h/statvfs.h"
 #  endif /* AFS_SUN5_ENV */
@@ -256,6 +263,10 @@ struct vop_getwritemount_args;
 #  include <sys/uio.h>
 #  include <sys/mount.h>
 #  include <sys/namei.h>
+#ifdef AFS_DARWIN80_ENV
+#  include <sys/kauth.h>
+#include <string.h>
+#endif
 #  include <sys/vnode.h>
 #  include <sys/queue.h>
 #  include <sys/malloc.h>
@@ -276,9 +287,11 @@ MALLOC_DECLARE(M_AFS);
 #undef timeout_fcn_t
 #define _DIR_H_
 #define doff_t          int32_t
+#ifndef AFS_DARWIN80_ENV
 #  include <ufs/ufs/quota.h>
 #  include <ufs/ufs/inode.h>
 #  include <ufs/ffs/fs.h>
+#endif
 #else
 #  include "h/vfs.h"
 #  include "h/vnode.h"
@@ -294,7 +307,6 @@ MALLOC_DECLARE(M_AFS);
 #    endif /* !AFS_AIX32_ENV */
 #  endif /* AFS_SUN5_ENV */
 #endif /* AFS_DARWIN_ENV || AFS_FBSD_ENV */
-#endif /* AFS_DEC_ENV */
 
 /* These mainly deal with networking and rpc headers */
 #include "netinet/in.h"
@@ -310,10 +322,6 @@ MALLOC_DECLARE(M_AFS);
 #include "rpc/types.h"
 #include "rx/xdr.h"
 
-#ifdef AFS_AIX32_ENV
-#  include "net/spl.h"
-#endif
-
 /* Miscellaneous headers */
 #include "h/proc.h"
 #if !defined(AFS_FBSD_ENV)
@@ -330,19 +338,19 @@ MALLOC_DECLARE(M_AFS);
 #include "h/tty.h"
 #endif
 
-#if !defined(AFS_SGI_ENV) && !defined(AFS_SUN_ENV) && !defined(AFS_MACH_ENV) && !defined(AFS_AIX32_ENV) && !defined(AFS_HPUX_ENV) && !defined(AFS_SUN5_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
+#if !defined(AFS_SGI_ENV) && !defined(AFS_AIX32_ENV) && !defined(AFS_HPUX_ENV) && !defined(AFS_SUN5_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
 
 #  include "h/text.h"
 #endif
 
 
-#if	defined(AFS_AIX_ENV) || defined(AFS_DEC_ENV)
+#if	defined(AFS_AIX_ENV) 
 #  include "h/flock.h"		/* fcntl.h is a user-level include in aix */
 #else
 #  include "h/fcntl.h"
-#endif /* AIX || DEC */
+#endif /* AIX */
 
-#if defined(AFS_SGI_ENV) || defined(AFS_SUN_ENV) || defined(AFS_SUN5_ENV)
+#if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV)
 #  include "h/unistd.h"
 #endif /* SGI || SUN */
 
@@ -395,13 +403,13 @@ MALLOC_DECLARE(M_AFS);
 #include <sys/mbuf.h>
 #include <rpc/types.h>
 
-#ifdef	AFS_ALPHA_ENV
+#ifdef	AFS_OSF_ENV
 #undef kmem_alloc
 #undef kmem_free
 #undef mem_alloc
 #undef mem_free
 #undef register
-#endif /* AFS_ALPHA_ENV */
+#endif /* AFS_OSF_ENV */
 
 #include <rx/xdr.h>
 #include <sys/proc.h>
